@@ -1,5 +1,5 @@
-import setup_pyAMI
- # the above line needed to ensure correct python environment since pyAMI 4.0.3
+
+
 from pyAMI.client import AMIClient
 from pyAMI.query import get_datasets, print_table
 from pyAMI.auth import AMI_CONFIG, create_auth_config
