@@ -1,5 +1,4 @@
-import setup_pyAMI
- # the above line needed to ensure correct python environment since pyAMI 4.0.3
+
 from pyAMI import endpoint
 from pyAMI.client import AMIClient
 from pyAMI.endpoint import get_endpoint,get_XSL_URL
