@@ -12,12 +12,13 @@ Solveig Albrand
 Noel Dawe
 Jerome Fulachier
 Fabian Lambert
+Jerome Odier
 
 """
 
-VERSION = '4.1.1'
+VERSION = '4.1.3'
 AUTHOR_EMAIL = 'atlas-bookkeeping@cern.ch'
-URL = 'https://end.web.cern.ch/end/projects/pyAMI/'
+URL = 'https://atlas-ami.cern.ch/AMI/pyAMI/'
 DOWNLOAD_URL = 'http://pypi.python.org/packages/source/p/pyAMI/pyAMI-%s.tar.gz' % VERSION
 
 __doc__ %= VERSION
