@@ -705,7 +705,7 @@ def get_data_datasets(client,
                             parent_type=parent_type,
                             **kwargs)
 
-    if latest:
+    if latest and False:
         if type.startswith('NTUP'):
             VERSION_PATTERN = NTUP_VERSION_PATTERN
         elif type.startswith('AOD'):
