@@ -79,6 +79,11 @@ class DATASET_TABLE(Table):
         'beam': 'beamType',
         'conditions_tag': 'conditionsTag',
         'total_size': 'totalSize',
+        'ecm_energy': 'ecmEnergy',
+        'generator_name': 'generatorName',
+        'generator_tune': 'generatorTune',
+        'pdf': 'PDF',
+        'cross_section': 'crossSection',
     }
 
     defaults = {
